@@ -52,7 +52,7 @@ L<DBIx::POS::Template>
 =sql
 
   select *
-  from {% $schema %}users
+  from "{% $schema %}".users
   where id = ? or login=?
 
 =item * B<apply routes> 
@@ -64,19 +64,19 @@ L<DBIx::POS::Template>
 =sql
 
   select r.*, ac.controller, ac.namespace, ac.action, ac.callback, ac.id as action_id, ac.controller_id, ac.namespace_id
-  from {% $schema %}routes r
-    join {% $schema %}refs rf on r.id=rf.id1
+  from "{% $schema %}".routes r
+    join "{% $schema %}".refs rf on r.id=rf.id1
     join 
     (
       select a.*, c.*
-      from {% $schema %}actions a 
+      from "{% $schema %}".actions a 
       left join (
         select r.id2 as _id, c.controller, c.id as controller_id, n.namespace, n.id as namespace_id
         from 
-          {% $schema %}refs r
-          join {% $schema %}controllers c on r.id1=c.id
-          left join {% $schema %}refs r2 on c.id=r2.id2
-          left join {% $schema %}namespaces n on n.id=r2.id1
+          "{% $schema %}".refs r
+          join "{% $schema %}".controllers c on r.id1=c.id
+          left join "{% $schema %}".refs r2 on c.id=r2.id2
+          left join "{% $schema %}".namespaces n on n.id=r2.id1
       ) c on a.id=c._id
     ) ac on rf.id2=ac.id
   order by r.ts - (coalesce(r.interval_ts, 0::int)::varchar || ' second')::interval;
@@ -95,8 +95,8 @@ L<DBIx::POS::Template>
 
   select g.*
   from
-    {% $schema %}roles g
-    join {% $schema %}refs r on g.id=r.id1
+    "{% $schema %}".roles g
+    join "{% $schema %}".refs r on g.id=r.id1
   where r.id2=?;
   --and coalesce(g.disable, 0::bit) <> 1::bit
 
@@ -113,7 +113,7 @@ L<DBIx::POS::Template>
 =sql
 
   select count(*)
-  from {% $schema %}refs
+  from "{% $schema %}".refs
   where id1 = any(?) and id2 = ANY(?);
 
 =item * B<access action>
@@ -130,10 +130,10 @@ L<DBIx::POS::Template>
 
   select count(r.*)
   from
-    {% $schema %}refs rc 
-    join {% $schema %}actions a on a.id=rc.id2
-    join {% $schema %}refs r on a.id=r.id1
-    ---join {% $schema %}roles o on o.id=r.id2
+    "{% $schema %}".refs rc 
+    join "{% $schema %}".actions a on a.id=rc.id2
+    join "{% $schema %}".refs r on a.id=r.id1
+    ---join "{% $schema %}".roles o on o.id=r.id2
   where
     rc.id1=? ---controller id
     and a.action=?
@@ -156,9 +156,9 @@ L<DBIx::POS::Template>
 
   select count(n.*)
   from 
-    {% $schema %}namespaces n
-    join {% $schema %}refs r on n.id=r.id1
-    ---join {% $schema %}roles o on r.id2=o.id
+    "{% $schema %}".namespaces n
+    join "{% $schema %}".refs r on n.id=r.id1
+    ---join "{% $schema %}".roles o on r.id2=o.id
   where
     n.namespace=?
     and r.id2=any(?) --- roles ids
@@ -178,7 +178,7 @@ L<DBIx::POS::Template>
 =sql
 
   select count(*)
-  from {% $schema %}roles
+  from "{% $schema %}".roles
   where (id = ? or name = ?)
     and id = any(?)
     and coalesce(disable, 0::bit) <> 1::bit
@@ -198,7 +198,7 @@ L<DBIx::POS::Template>
 
 =sql
 
-  insert into {% $schema %}users (login, pass) values (?,?)
+  insert into "{% $schema %}".users (login, pass) values (?,?)
   returning *;
 
 =item * B<role> 
@@ -210,7 +210,7 @@ L<DBIx::POS::Template>
 =sql
 
   select *
-  from {% $schema %}roles
+  from "{% $schema %}".roles
   where id=? or lower(name)=?
 
 =item * B<new role> 
@@ -221,7 +221,7 @@ L<DBIx::POS::Template>
 
 =sql
 
-  insert into {% $schema %}roles (name) values (?)
+  insert into "{% $schema %}".roles (name) values (?)
   returning *;
 
 =item * B<dsbl/enbl role> 
@@ -232,7 +232,7 @@ L<DBIx::POS::Template>
 
 =sql
 
-  update {% $schema %}roles set disable=?::bit where id=? or lower(name)=?
+  update "{% $schema %}".roles set disable=?::bit where id=? or lower(name)=?
   returning *;
 
 =item * B<ref> 
@@ -244,7 +244,7 @@ L<DBIx::POS::Template>
 =sql
 
   select *
-  from {% $schema %}refs
+  from "{% $schema %}".refs
   where id1=? and id2=?;
 
 =item * B<new ref> 
@@ -255,7 +255,7 @@ L<DBIx::POS::Template>
 
 =sql
 
-  insert into {% $schema %}refs (id1,id2) values (?,?)
+  insert into "{% $schema %}".refs (id1,id2) values (?,?)
   returning *;
 
 
@@ -267,7 +267,7 @@ L<DBIx::POS::Template>
 
 =sql
 
-  delete from {% $schema %}refs
+  delete from "{% $schema %}".refs
   where id1=? and id2=?
   returning *;
 
@@ -286,9 +286,9 @@ L<DBIx::POS::Template>
   select * from (
   select c.*, n.namespace, n.id as namespace_id, n.descr as namespace_descr
   from
-    {% $schema %}controllers c
-    left join {% $schema %}refs r on c.id=r.id2
-    left join {% $schema %}namespaces n on n.id=r.id1
+    "{% $schema %}".controllers c
+    left join "{% $schema %}".refs r on c.id=r.id2
+    left join "{% $schema %}".namespaces n on n.id=r.id1
   ) s
   {% $where %}
 
@@ -300,7 +300,7 @@ L<DBIx::POS::Template>
 
 =sql
 
-  insert into {% $schema %}controllers (controller, descr)
+  insert into "{% $schema %}".controllers (controller, descr)
   values (?,?)
   returning *;
 
@@ -314,11 +314,11 @@ L<DBIx::POS::Template>
 
   select * from (
   select r.*, s.action_id
-  from {% $schema %}routes r
+  from "{% $schema %}".routes r
     left join (
      select s.id1, a.id as action_id
-     from {% $schema %}refs s
-      join {% $schema %}actions a on a.id=s.id2
+     from "{% $schema %}".refs s
+      join "{% $schema %}".actions a on a.id=s.id2
     ) s on r.id=s.id1
   ) s
   {% $where %}; -- action_id is null - free routes; or action(id) routes
@@ -333,7 +333,7 @@ L<DBIx::POS::Template>
 
 =sql
 
-  insert into {% $schema %}routes (request, name, descr, auth, disable, interval_ts)
+  insert into "{% $schema %}".routes (request, name, descr, auth, disable, interval_ts)
   values (?,?,?,?,?,?)
   returning *;
 
@@ -347,8 +347,8 @@ L<DBIx::POS::Template>
 
   select u.*
   from
-    {% $schema %}users u
-    join {% $schema %}refs r on u.id=r.id2
+    "{% $schema %}".users u
+    join "{% $schema %}".refs r on u.id=r.id2
   where r.id1=?;
 
 =item * B<role routes> 
@@ -361,8 +361,8 @@ L<DBIx::POS::Template>
 
   select t.*
   from
-    {% $schema %}routes t
-    join {% $schema %}refs r on t.id=r.id1
+    "{% $schema %}".routes t
+    join "{% $schema %}".refs r on t.id=r.id1
   where r.id2=?;
 
 
@@ -375,9 +375,9 @@ L<DBIx::POS::Template>
 =sql
 
   select c.*, n.namespace, n.id as namespace_id, n.descr as namespace_descr
-    from {% $schema %}controllers c
-    left join {% $schema %}refs r on c.id=r.id2
-    left join {% $schema %}namespaces n on n.id=r.id1
+    from "{% $schema %}".controllers c
+    left join "{% $schema %}".refs r on c.id=r.id2
+    left join "{% $schema %}".namespaces n on n.id=r.id1
     {% $where %};
 
 =item * B<namespaces>
@@ -389,7 +389,7 @@ L<DBIx::POS::Template>
 =sql
 
   select *
-  from {% $schema %}namespaces
+  from "{% $schema %}".namespaces
   {% $where %}
   {% $order %};
 
@@ -402,7 +402,7 @@ L<DBIx::POS::Template>
 =sql
 
   select *
-  from {% $schema %}namespaces
+  from "{% $schema %}".namespaces
   where id=? or namespace = ?;
 
 =item * B<new namespace>
@@ -413,7 +413,7 @@ L<DBIx::POS::Template>
 
 =sql
 
-  insert into {% $schema %}namespaces (namespace, descr, app_ns, interval_ts) values (?,?,?,?)
+  insert into "{% $schema %}".namespaces (namespace, descr, app_ns, interval_ts) values (?,?,?,?)
   returning *;
 
 
@@ -427,12 +427,12 @@ L<DBIx::POS::Template>
 
   select * from (
   select a.*, ac.controller_id, ac.controller
-  from {% $schema %}actions a
+  from "{% $schema %}".actions a
     left join (
       select a.id, c.id as controller_id, c.controller
-      from {% $schema %}actions a
-        join {% $schema %}refs r on a.id=r.id2
-        join {% $schema %}controllers c on c.id=r.id1
+      from "{% $schema %}".actions a
+        join "{% $schema %}".refs r on a.id=r.id2
+        join "{% $schema %}".controllers c on c.id=r.id1
       ) ac on a.id=ac.id-- действия с контроллером
   ) as a
   {% $where %}
@@ -445,7 +445,7 @@ L<DBIx::POS::Template>
 
 =sql
 
-  insert into {% $schema %}actions (action, callback, descr)
+  insert into "{% $schema %}".actions (action, callback, descr)
   values (?,?,?)
   returning *;
 
